Changelog
---------

This package does not contain a changelog by itself as it merely acts as a
meta-package for OneGov Cloud applications. To list the changes made to
these applications have a look at the individual application releases.

To find out which application releases were included in a onegov.applications
release have a look at the requirements.txt on GitHub:

https://github.com/OneGov/onegov.applications/releases
